# m3c2

Multi-Chain MCMC sampler

1. Sampler which runs several chains in parallel to check the overall convergence
2. Sampler which uses parallel tempering

The sampler combined slice-sampling Metropolis-Hastings step and
delayed rejection Metropolis_Hastings step (under developemnt)

## Installation

``` shell
pip install .
```


